@@ -1,7 +1,7 @@
 package Test::Rinci;
 
-our $DATE = '2015-09-06'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2016-01-19'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use strict;
@@ -84,10 +84,10 @@ sub _test_function_metadata {
                     $Test->is_num($r->[0], $eg->{status} // 200, "status")
                         or do { $Test->diag($Test->explain($r)); $ok = 0 };
                     if (exists $eg->{result}) {
-                        Test::More::is_deeply($r->[2], $eg->{result}, "result")
+                        Test::More::is_deeply($r, $eg->{result}, "result")
                               or do {
                                   Test::More::diag(
-                                      Test::More::explain($r->[2]));
+                                      Test::More::explain($r));
                                   $ok = 0;
                               };
                     }
@@ -299,7 +299,7 @@ Test::Rinci - Test Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.10 of Test::Rinci (from Perl distribution Test-Rinci), released on 2015-09-06.
+This document describes version 0.11 of Test::Rinci (from Perl distribution Test-Rinci), released on 2016-01-19.
 
 =head1 SYNOPSIS
 
@@ -327,6 +327,10 @@ easy to do so.
 
 =for Pod::Coverage ^(all_modules)$
 
+=head1 ACKNOWLEDGEMENTS
+
+Some code taken from L<Test::Pod::Coverage> by Andy Lester.
+
 =head1 FUNCTIONS
 
 All these functions are exported by default.
@@ -387,9 +391,21 @@ C<run metadata_in_module_ok()> on each of them.
 
 Options are the same as in C<metadata_in_module_ok()>.
 
-=head1 ACKNOWLEDGEMENTS
+=head1 HOMEPAGE
 
-Some code taken from L<Test::Pod::Coverage> by Andy Lester.
+Please visit the project's homepage at L<https://metacpan.org/release/Test-Rinci>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-Test-Rinci>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test-Rinci>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 SEE ALSO
 
@@ -401,29 +417,13 @@ L<Perinci::Sub::Wrapper>
 
 L<Dist::Zilla::Plugin::Test::Rinci>
 
-=head1 HOMEPAGE
-
-Please visit the project's homepage at L<https://metacpan.org/release/Test-Rinci>.
-
-=head1 SOURCE
-
-Source repository is at L<https://github.com/sharyanto/perl-Test-Rinci>.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test-Rinci>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
